@@ -2344,7 +2344,12 @@ module.exports = {
 		"35.3.0",
 		"35.4.0",
 		"35.5.0",
-		"35.5.1"
+		"35.5.1",
+		"35.6.0",
+		"35.7.0",
+		"35.7.1",
+		"35.7.2",
+		"35.7.4"
 	],
 	"135.0.7049.5": [
 		"36.0.0-alpha.1"
@@ -2394,6 +2399,16 @@ module.exports = {
 	"136.0.7103.149": [
 		"36.4.0"
 	],
+	"136.0.7103.168": [
+		"36.5.0"
+	],
+	"136.0.7103.177": [
+		"36.6.0",
+		"36.7.0",
+		"36.7.1",
+		"36.7.3",
+		"36.7.4"
+	],
 	"137.0.7151.0": [
 		"37.0.0-alpha.1",
 		"37.0.0-alpha.2"
@@ -2417,6 +2432,65 @@ module.exports = {
 		"37.0.0-beta.3"
 	],
 	"138.0.7204.15": [
-		"37.0.0-beta.4"
+		"37.0.0-beta.4",
+		"37.0.0-beta.5",
+		"37.0.0-beta.6",
+		"37.0.0-beta.7"
+	],
+	"138.0.7204.23": [
+		"37.0.0-beta.8"
+	],
+	"138.0.7204.35": [
+		"37.0.0-beta.9",
+		"37.0.0",
+		"37.1.0"
+	],
+	"138.0.7204.97": [
+		"37.2.0",
+		"37.2.1"
+	],
+	"138.0.7204.100": [
+		"37.2.2",
+		"37.2.3"
+	],
+	"138.0.7204.157": [
+		"37.2.4"
+	],
+	"138.0.7204.168": [
+		"37.2.5"
+	],
+	"138.0.7204.185": [
+		"37.2.6"
+	],
+	"139.0.7219.0": [
+		"38.0.0-alpha.1",
+		"38.0.0-alpha.2",
+		"38.0.0-alpha.3"
+	],
+	"140.0.7261.0": [
+		"38.0.0-alpha.4",
+		"38.0.0-alpha.5",
+		"38.0.0-alpha.6"
+	],
+	"140.0.7281.0": [
+		"38.0.0-alpha.7",
+		"38.0.0-alpha.8"
+	],
+	"140.0.7301.0": [
+		"38.0.0-alpha.9"
+	],
+	"140.0.7309.0": [
+		"38.0.0-alpha.10"
+	],
+	"140.0.7312.0": [
+		"38.0.0-alpha.11"
+	],
+	"140.0.7314.0": [
+		"38.0.0-alpha.12",
+		"38.0.0-alpha.13",
+		"38.0.0-beta.1"
+	],
+	"140.0.7327.0": [
+		"38.0.0-beta.2"
 	]
 };
\ No newline at end of file
