@@ -1526,6 +1526,11 @@ module.exports = {
 	"35.4.0": "134.0.6998.205",
 	"35.5.0": "134.0.6998.205",
 	"35.5.1": "134.0.6998.205",
+	"35.6.0": "134.0.6998.205",
+	"35.7.0": "134.0.6998.205",
+	"35.7.1": "134.0.6998.205",
+	"35.7.2": "134.0.6998.205",
+	"35.7.4": "134.0.6998.205",
 	"36.0.0-alpha.1": "135.0.7049.5",
 	"36.0.0-alpha.2": "136.0.7062.0",
 	"36.0.0-alpha.3": "136.0.7062.0",
@@ -1550,6 +1555,12 @@ module.exports = {
 	"36.3.1": "136.0.7103.113",
 	"36.3.2": "136.0.7103.115",
 	"36.4.0": "136.0.7103.149",
+	"36.5.0": "136.0.7103.168",
+	"36.6.0": "136.0.7103.177",
+	"36.7.0": "136.0.7103.177",
+	"36.7.1": "136.0.7103.177",
+	"36.7.3": "136.0.7103.177",
+	"36.7.4": "136.0.7103.177",
 	"37.0.0-alpha.1": "137.0.7151.0",
 	"37.0.0-alpha.2": "137.0.7151.0",
 	"37.0.0-alpha.3": "138.0.7156.0",
@@ -1560,5 +1571,34 @@ module.exports = {
 	"37.0.0-beta.1": "138.0.7178.0",
 	"37.0.0-beta.2": "138.0.7178.0",
 	"37.0.0-beta.3": "138.0.7190.0",
-	"37.0.0-beta.4": "138.0.7204.15"
+	"37.0.0-beta.4": "138.0.7204.15",
+	"37.0.0-beta.5": "138.0.7204.15",
+	"37.0.0-beta.6": "138.0.7204.15",
+	"37.0.0-beta.7": "138.0.7204.15",
+	"37.0.0-beta.8": "138.0.7204.23",
+	"37.0.0-beta.9": "138.0.7204.35",
+	"37.0.0": "138.0.7204.35",
+	"37.1.0": "138.0.7204.35",
+	"37.2.0": "138.0.7204.97",
+	"37.2.1": "138.0.7204.97",
+	"37.2.2": "138.0.7204.100",
+	"37.2.3": "138.0.7204.100",
+	"37.2.4": "138.0.7204.157",
+	"37.2.5": "138.0.7204.168",
+	"37.2.6": "138.0.7204.185",
+	"38.0.0-alpha.1": "139.0.7219.0",
+	"38.0.0-alpha.2": "139.0.7219.0",
+	"38.0.0-alpha.3": "139.0.7219.0",
+	"38.0.0-alpha.4": "140.0.7261.0",
+	"38.0.0-alpha.5": "140.0.7261.0",
+	"38.0.0-alpha.6": "140.0.7261.0",
+	"38.0.0-alpha.7": "140.0.7281.0",
+	"38.0.0-alpha.8": "140.0.7281.0",
+	"38.0.0-alpha.9": "140.0.7301.0",
+	"38.0.0-alpha.10": "140.0.7309.0",
+	"38.0.0-alpha.11": "140.0.7312.0",
+	"38.0.0-alpha.12": "140.0.7314.0",
+	"38.0.0-alpha.13": "140.0.7314.0",
+	"38.0.0-beta.1": "140.0.7314.0",
+	"38.0.0-beta.2": "140.0.7327.0"
 };
\ No newline at end of file
